"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EscrwWorldsActionProcessorTaskMapper = exports.EscrwWorldsActionMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const approve_mapper_1 = require("./approve.mapper");
const cancel_mapper_1 = require("./cancel.mapper");
const clean_mapper_1 = require("./clean.mapper");
const disapprove_mapper_1 = require("./disapprove.mapper");
const dispute_mapper_1 = require("./dispute.mapper");
const init_mapper_1 = require("./init.mapper");
const refund_mapper_1 = require("./refund.mapper");
const transfer_mapper_1 = require("./transfer.mapper");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const enums_1 = require("../../domain/enums");
class EscrwWorldsActionMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    fromEntity(entity) {
        let entityData;
        switch (entity.name) {
            case enums_1.EscrwWorldsActionName.Approve:
                entityData = new approve_mapper_1.ApproveMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.EscrwWorldsActionName.Cancel:
                entityData = new cancel_mapper_1.CancelMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.EscrwWorldsActionName.Clean:
                entityData = new clean_mapper_1.CleanMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.EscrwWorldsActionName.Disapprove:
                entityData = new disapprove_mapper_1.DisapproveMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.EscrwWorldsActionName.Dispute:
                entityData = new dispute_mapper_1.DisputeMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.EscrwWorldsActionName.Init:
                entityData = new init_mapper_1.InitMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.EscrwWorldsActionName.Refund:
                entityData = new refund_mapper_1.RefundMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.EscrwWorldsActionName.Transfer:
                entityData = new transfer_mapper_1.TransferMongoMapper().fromEntity(entity.data);
                break;
        }
        const model = {
            block_timestamp: entity.blockTimestamp,
            block_number: new aw_storage_mongodb_1.MongoDB.Long(entity.blockNumber),
            global_sequence: new aw_storage_mongodb_1.MongoDB.Long(entity.globalSequence),
            receiver_sequence: new aw_storage_mongodb_1.MongoDB.Long(entity.receiverSequence),
            trx_id: entity.transactionId,
            action: {
                name: entity.name,
                account: entity.account,
                data: entityData,
            },
        };
        if (entity.id && aw_storage_mongodb_1.MongoDB.ObjectId.isValid(entity.id)) {
            model._id = new aw_storage_mongodb_1.MongoDB.ObjectId(entity.id);
        }
        return model;
    }
    toEntity(mongoModel) {
        let data;
        switch (mongoModel.action.name) {
            case enums_1.EscrwWorldsActionName.Approve:
                data = new approve_mapper_1.ApproveMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.EscrwWorldsActionName.Cancel:
                data = new cancel_mapper_1.CancelMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.EscrwWorldsActionName.Clean:
                data = new clean_mapper_1.CleanMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.EscrwWorldsActionName.Disapprove:
                data = new disapprove_mapper_1.DisapproveMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.EscrwWorldsActionName.Dispute:
                data = new dispute_mapper_1.DisputeMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.EscrwWorldsActionName.Init:
                data = new init_mapper_1.InitMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.EscrwWorldsActionName.Refund:
                data = new refund_mapper_1.RefundMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.EscrwWorldsActionName.Transfer:
                data = new transfer_mapper_1.TransferMongoMapper().toEntity(mongoModel.action.data);
                break;
        }
        const { _id, block_timestamp, block_number, global_sequence, receiver_sequence, trx_id, action, } = mongoModel;
        return new aw_core_1.ContractAction(_id.toString(), block_timestamp, (0, aw_core_1.parseToBigInt)(block_number), action.account, action.name, (0, aw_core_1.parseToBigInt)(global_sequence), (0, aw_core_1.parseToBigInt)(receiver_sequence), trx_id, data);
    }
}
exports.EscrwWorldsActionMongoMapper = EscrwWorldsActionMongoMapper;
class EscrwWorldsActionProcessorTaskMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('method not implemented');
    }
    toEntity(rawModel) {
        let data;
        switch (rawModel.name) {
            case enums_1.EscrwWorldsActionName.Approve:
                data = new approve_mapper_1.ApproveRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.EscrwWorldsActionName.Cancel:
                data = new cancel_mapper_1.CancelRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.EscrwWorldsActionName.Clean:
                data = new clean_mapper_1.CleanRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.EscrwWorldsActionName.Disapprove:
                data = new disapprove_mapper_1.DisapproveRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.EscrwWorldsActionName.Dispute:
                data = new dispute_mapper_1.DisputeRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.EscrwWorldsActionName.Init:
                data = new init_mapper_1.InitRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.EscrwWorldsActionName.Refund:
                data = new refund_mapper_1.RefundRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.EscrwWorldsActionName.Transfer:
                data = new transfer_mapper_1.TransferRawMapper().toEntity(rawModel.data);
                break;
        }
        const { account, name, block_timestamp, block_number, global_sequence, recv_sequence, transaction_id, } = rawModel;
        return new aw_core_1.ContractAction('', block_timestamp, (0, aw_core_1.parseToBigInt)(block_number), account, name, (0, aw_core_1.parseToBigInt)(global_sequence), (0, aw_core_1.parseToBigInt)(recv_sequence), transaction_id, data);
    }
}
exports.EscrwWorldsActionProcessorTaskMapper = EscrwWorldsActionProcessorTaskMapper;
