"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EscrowsRawMapper = exports.EscrowsMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const aw_antelope_1 = require("@alien-worlds/aw-antelope");
const entities_1 = require("../../domain/entities");
class EscrowsMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    constructor() {
        super();
        this.mappingFromEntity.set('key', {
            key: 'key',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('sender', {
            key: 'sender',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('receiver', {
            key: 'receiver',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('arb', {
            key: 'arb',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('receiverPay', {
            key: 'receiver_pay',
            mapper: (value) => new aw_antelope_1.ExtendedAssetMongoMapper().fromEntity(value),
        });
        this.mappingFromEntity.set('arbitratorPay', {
            key: 'arbitrator_pay',
            mapper: (value) => new aw_antelope_1.ExtendedAssetMongoMapper().fromEntity(value),
        });
        this.mappingFromEntity.set('memo', {
            key: 'memo',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('expires', {
            key: 'expires',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('disputed', {
            key: 'disputed',
            mapper: (value) => value,
        });
    }
    toEntity(mongoModel) {
        const { key, sender, receiver, arb, receiver_pay, arbitrator_pay, memo, expires, disputed, _id, ...rest } = mongoModel;
        return entities_1.Escrows.create(key || '', sender || '', receiver || '', arb || '', receiver_pay ? new aw_antelope_1.ExtendedAssetMongoMapper().toEntity(receiver_pay) : aw_antelope_1.ExtendedAsset.getDefault(), arbitrator_pay ? new aw_antelope_1.ExtendedAssetMongoMapper().toEntity(arbitrator_pay) : aw_antelope_1.ExtendedAsset.getDefault(), memo || '', expires || new Date(0), disputed || false, _id instanceof aw_storage_mongodb_1.MongoDB.ObjectId ? _id.toString() : undefined, rest);
    }
}
exports.EscrowsMongoMapper = EscrowsMongoMapper;
class EscrowsRawMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('Method not implemented');
    }
    toEntity(rawModel) {
        const { key, sender, receiver, arb, receiver_pay, arbitrator_pay, memo, expires, disputed, ...rest } = rawModel;
        return entities_1.Escrows.create(key || '', sender || '', receiver || '', arb || '', receiver_pay ? new aw_antelope_1.ExtendedAssetRawMapper().toEntity(receiver_pay) : aw_antelope_1.ExtendedAsset.getDefault(), arbitrator_pay ? new aw_antelope_1.ExtendedAssetRawMapper().toEntity(arbitrator_pay) : aw_antelope_1.ExtendedAsset.getDefault(), memo || '', expires || new Date(0), disputed || false, undefined, rest);
    }
}
exports.EscrowsRawMapper = EscrowsRawMapper;
