"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupEscrwWorldsContractService = exports.setupEscrwWorldsDeltaRepository = exports.setupEscrwWorldsActionRepository = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const mappers_1 = require("./actions/data/mappers");
const data_sources_1 = require("./actions/data/data-sources");
const repositories_1 = require("./actions/domain/repositories");
const escrw_worlds_contract_service_1 = require("./services/escrw-worlds-contract.service");
const escrw_worlds_contract_service_impl_1 = require("./services/escrw-worlds-contract.service-impl");
const mappers_2 = require("./deltas/data/mappers");
const data_sources_2 = require("./deltas/data/data-sources");
const repositories_2 = require("./deltas/domain/repositories");
const setupEscrwWorldsActionRepository = async (mongo, container) => {
    let mongoSource;
    if (mongo instanceof aw_storage_mongodb_1.MongoSource) {
        mongoSource = mongo;
    }
    else {
        mongoSource = await aw_storage_mongodb_1.MongoSource.create(mongo);
    }
    const mapper = new mappers_1.EscrwWorldsActionMongoMapper();
    const repository = new aw_core_1.RepositoryImpl(new data_sources_1.EscrwWorldsActionMongoSource(mongoSource), mapper, new aw_storage_mongodb_1.MongoQueryBuilders(mapper));
    if (container) {
        container
            .bind(repositories_1.EscrwWorldsActionRepository.Token)
            .toConstantValue(repository);
    }
    return repository;
};
exports.setupEscrwWorldsActionRepository = setupEscrwWorldsActionRepository;
const setupEscrwWorldsDeltaRepository = async (mongo, container) => {
    let mongoSource;
    if (mongo instanceof aw_storage_mongodb_1.MongoSource) {
        mongoSource = mongo;
    }
    else {
        mongoSource = await aw_storage_mongodb_1.MongoSource.create(mongo);
    }
    const mapper = new mappers_2.EscrwWorldsDeltaMongoMapper();
    const repository = new aw_core_1.RepositoryImpl(new data_sources_2.EscrwWorldsDeltaMongoSource(mongoSource), mapper, new aw_storage_mongodb_1.MongoQueryBuilders(mapper));
    if (container) {
        container
            .bind(repositories_2.EscrwWorldsDeltaRepository.Token)
            .toConstantValue(repository);
    }
    return repository;
};
exports.setupEscrwWorldsDeltaRepository = setupEscrwWorldsDeltaRepository;
const setupEscrwWorldsContractService = (antelopeRpcSourceImpl, serviceUrl, container) => {
    const service = new escrw_worlds_contract_service_impl_1.EscrwWorldsContractServiceImpl(antelopeRpcSourceImpl, serviceUrl);
    if (container) {
        container
            .bind(escrw_worlds_contract_service_1.EscrwWorldsContractService.Token)
            .toConstantValue(service);
    }
    return service;
};
exports.setupEscrwWorldsContractService = setupEscrwWorldsContractService;
